@@ -32,7 +32,7 @@ logger = logging.getLogger(__name__)
 @click.group()
 @click.version_option(version=__version__)
 @click.option('--name', '-n', default=os.path.basename(os.getcwd()),
-              type=STR, show_default=True, help='reV Economics job name.')
+              type=STR, show_default=True, help='reV Generation job name.')
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging. Default is not verbose.')
 @click.pass_context
